Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8046)

Unified Diff: chrome/browser/ui/cocoa/page_info/page_info_bubble_controller.h

Issue 2754383004: Rename WebsiteSettings code to PageInfo. (Closed)
Patch Set: Upload missing comment fix for WebSettingsUI -> PageInfoUI. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/page_info/page_info_bubble_controller.h
diff --git a/chrome/browser/ui/cocoa/page_info/website_settings_bubble_controller.h b/chrome/browser/ui/cocoa/page_info/page_info_bubble_controller.h
similarity index 73%
rename from chrome/browser/ui/cocoa/page_info/website_settings_bubble_controller.h
rename to chrome/browser/ui/cocoa/page_info/page_info_bubble_controller.h
index 60d81c78e469013287089aaa4434faed6cb39804..1621db3a84fe96aaba50b6d603617ddca02b4da4 100644
--- a/chrome/browser/ui/cocoa/page_info/website_settings_bubble_controller.h
+++ b/chrome/browser/ui/cocoa/page_info/page_info_bubble_controller.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_COCOA_WEBSITE_SETTINGS_WEBSITE_SETTINGS_BUBBLE_CONTROLLER_H_
-#define CHROME_BROWSER_UI_COCOA_WEBSITE_SETTINGS_WEBSITE_SETTINGS_BUBBLE_CONTROLLER_H_
+#ifndef CHROME_BROWSER_UI_COCOA_PAGE_INFO_PAGE_INFO_BUBBLE_CONTROLLER_H_
+#define CHROME_BROWSER_UI_COCOA_PAGE_INFO_PAGE_INFO_BUBBLE_CONTROLLER_H_
#import <Cocoa/Cocoa.h>
@@ -12,10 +12,10 @@
#include "base/mac/scoped_nsobject.h"
#include "base/macros.h"
#import "chrome/browser/ui/cocoa/omnibox_decoration_bubble_controller.h"
-#include "chrome/browser/ui/page_info/website_settings_ui.h"
+#include "chrome/browser/ui/page_info/page_info_ui.h"
#include "content/public/browser/web_contents_observer.h"
-class WebsiteSettingsUIBridge;
+class PageInfoUIBridge;
namespace content {
class WebContents;
@@ -31,10 +31,7 @@ struct SecurityInfo;
// This NSWindowController subclass manages the InfoBubbleWindow and view that
// are displayed when the user clicks the favicon or security lock icon.
-//
-// TODO(palmer): Normalize all WebsiteSettings*, SiteSettings*, PageInfo*, et c.
-// to OriginInfo*.
-@interface WebsiteSettingsBubbleController : OmniboxDecorationBubbleController {
+@interface PageInfoBubbleController : OmniboxDecorationBubbleController {
@private
content::WebContents* webContents_;
@@ -92,20 +89,20 @@ struct SecurityInfo;
// The UI translates user actions to specific events and forwards them to the
// |presenter_|. The |presenter_| handles these events and updates the UI.
- std::unique_ptr<WebsiteSettings> presenter_;
+ std::unique_ptr<PageInfo> presenter_;
- // Bridge which implements the WebsiteSettingsUI interface and forwards
+ // Bridge which implements the PageInfoUI interface and forwards
// methods on to this class.
- std::unique_ptr<WebsiteSettingsUIBridge> bridge_;
+ std::unique_ptr<PageInfoUIBridge> bridge_;
}
// Designated initializer. The controller will release itself when the bubble
// is closed. |parentWindow| cannot be nil. |webContents| may be nil for
// testing purposes.
- (id)initWithParentWindow:(NSWindow*)parentWindow
- websiteSettingsUIBridge:(WebsiteSettingsUIBridge*)bridge
- webContents:(content::WebContents*)webContents
- url:(const GURL&)url;
+ pageInfoUIBridge:(PageInfoUIBridge*)bridge
+ webContents:(content::WebContents*)webContents
+ url:(const GURL&)url;
// Return the default width of the window. It may be wider to fit the content.
// This may be overriden by a subclass for testing purposes.
@@ -113,15 +110,15 @@ struct SecurityInfo;
@end
-// Provides a bridge between the WebSettingsUI C++ interface and the Cocoa
-// implementation in WebsiteSettingsBubbleController.
-class WebsiteSettingsUIBridge : public content::WebContentsObserver,
- public WebsiteSettingsUI {
+// Provides a bridge between the PageInfoUI C++ interface and the Cocoa
+// implementation in PageInfoBubbleController.
+class PageInfoUIBridge : public content::WebContentsObserver,
+ public PageInfoUI {
public:
- explicit WebsiteSettingsUIBridge(content::WebContents* web_contents);
- ~WebsiteSettingsUIBridge() override;
+ explicit PageInfoUIBridge(content::WebContents* web_contents);
+ ~PageInfoUIBridge() override;
- // Creates a |WebsiteSettingsBubbleController| and displays the UI. |parent|
+ // Creates a |PageInfoBubbleController| and displays the UI. |parent|
// is the currently active window. |profile| points to the currently active
// profile. |web_contents| points to the WebContents that wraps the currently
// active tab. |virtual_url| is the virtual GURL of the currently active
@@ -133,13 +130,12 @@ class WebsiteSettingsUIBridge : public content::WebContentsObserver,
const GURL& virtual_url,
const security_state::SecurityInfo& security_info);
- void set_bubble_controller(
- WebsiteSettingsBubbleController* bubble_controller);
+ void set_bubble_controller(PageInfoBubbleController* bubble_controller);
// WebContentsObserver implementation.
void RenderFrameDeleted(content::RenderFrameHost* render_frame_host) override;
- // WebsiteSettingsUI implementations.
+ // PageInfoUI implementations.
void SetCookieInfo(const CookieInfoList& cookie_info_list) override;
void SetPermissionInfo(const PermissionInfoList& permission_info_list,
ChosenObjectInfoList chosen_object_info_list) override;
@@ -150,9 +146,9 @@ class WebsiteSettingsUIBridge : public content::WebContentsObserver,
content::WebContents* web_contents_;
// The Cocoa controller for the bubble UI.
- WebsiteSettingsBubbleController* bubble_controller_;
+ PageInfoBubbleController* bubble_controller_;
- DISALLOW_COPY_AND_ASSIGN(WebsiteSettingsUIBridge);
+ DISALLOW_COPY_AND_ASSIGN(PageInfoUIBridge);
};
-#endif // CHROME_BROWSER_UI_COCOA_WEBSITE_SETTINGS_WEBSITE_SETTINGS_BUBBLE_CONTROLLER_H_
+#endif // CHROME_BROWSER_UI_COCOA_PAGE_INFO_PAGE_INFO_BUBBLE_CONTROLLER_H_

Powered by Google App Engine
This is Rietveld 408576698